@@ -1,6 +1,6 @@
 import calendar;
 import time;
-from mysql_helper import execute_select_for_results, execute as mysql_execute,  get_mysql_connection
+from .mysql_helper import execute_select_for_results, execute as mysql_execute,  get_mysql_connection
 
 def generate_file_name(prefix="pax_terminals_details"):
   return f"{prefix}_{calendar.timegm(time.gmtime())}.csv"
